clc, clear
format long
%% initiate model skeleton structure
LEG_PELVIS_TORSO_mech_parameter;    % statistical calculation of the body segments properties

%% initiate muscle parameter for dynamics
Leg_Dynamics_para;                 % Parameters for torque and muscle length calculation

%% Initial starting conditions

% the hip joint angle needs to be bigger than 90 deg -> the implemented joint is limited to 90 deg

start_position.phi_hip_left_forward  =  120; % start position left hip  
start_position.phi_hip_right_forward =  start_position.phi_hip_left_forward; % start position right hip 

start_position.phi_knee_left  = 80;  % start position left knee 
start_position.phi_knee_right = start_position.phi_knee_left;  % start position right knee 

% calculation of the ankle starting position
start_position.phi_ankle_left  = start_position.phi_hip_left_forward-...
                                 start_position.phi_knee_left; 
start_position.phi_ankle_right = start_position.phi_hip_right_forward-...
                                 start_position.phi_knee_right;

% Height of the (1-DOF, 2-DOF, 6-DOF) joint between the ground and the pelvis 
start_position.start_height = skeleton.Pelvis.length/2+...
                              skeleton.leg.upper.length*...
                              sind(start_position.phi_hip_left_forward-90)+...
                              skeleton.leg.lower.length*...
                              cosd(start_position.phi_ankle_left)+...
                              skeleton.foot.height;
                            
%% initiate all muscles

start_position.mus_act.HFL = 0.9;  % [] initial muscle activity 0...1 HFL
Muscle_Hip_flexors;                % flexor
start_position.mus_act.GLU = 0.5;  % [] initial muscle activity 0...1 GLU
Muscle_Gluteus;                    % extender
start_position.mus_act.HAM = 0.5;  % [] initial muscle activity 0...1 HAM
Muscle_Hamstring;                  % extender 2

clear Param_Mus                    % delete unnecessary parameters

%% parameters for the calculation of the linear motion conversion from hip joint to others
 
regulation.limit_hip_upper = 180;       % upper limit of the hip moition
regulation.limit_knee_upper = 175;      % upper limit of the knee motion
regulation.limit_foot_upper = -20;      % upper limit of the ankle motion

% hip to knee angle motion conversion
regulation.hip_to_knee.a = (start_position.phi_knee_left- ...
                           regulation.limit_knee_upper)/...
                           (start_position.phi_hip_left_forward-...
                           regulation.limit_hip_upper); % a of the linear interpolation
regulation.hip_to_knee.b = regulation.limit_knee_upper-...
                           regulation.hip_to_knee.a*...
                           regulation.limit_hip_upper;  % b of the linear interpolation

% hip to ankel angle motion conversion (no final implementation)                       
regulation.hip_to_ankel.a = (start_position.phi_ankle_left- ...
                            regulation.limit_foot_upper)/...
                            (start_position.phi_hip_left_forward-...
                            regulation.limit_hip_upper);
regulation.hip_to_ankel.b = regulation.limit_foot_upper-...
                            regulation.hip_to_ankel.a*...
                            regulation.limit_foot_upper;

% Copyright (c) 2019 belongs to A. Seidel